resume

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: GPL-3.0 Imports: 10 Imported by: 0

README

go-resume

An HTTP server which generates a PDF for the purposes of getting me more work

Prospective employers

If you came here via the QR code on my resume, thanks for checking it out. I would like to work for you!

Other interested parties

If you want to run this locally, you'll need to download the following fonts and put them in ./fonts:

To run, just clone this repo and git run . from your command line.

Options

This server supports some query options:

  • color=000000 change the font colour to any hex value
  • accent=646464 change the accent colour to any hex value
  • short=true generate a one-pager instead of two

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Resume

func Resume(w http.ResponseWriter, r *http.Request)

Types

type Font

type Font struct {
	// contains filtered or unexported fields
}

type MajorProject

type MajorProject struct {
	Company      string
	Title        string
	Start        string
	End          string
	Description  string
	Achievements []string
}

type PDFSettings

type PDFSettings struct {
	// contains filtered or unexported fields
}

type PageStyle

type PageStyle struct {
	// contains filtered or unexported fields
}

type Person

type Person struct {
	FirstName       string
	LastName        string
	Location        string
	Phone           string
	Email           string
	LinkedIn        string
	GitHub          string
	Url             string
	QrUrl           string
	Summary         string
	TechnicalSkills []TechSkill
	JobHistory      []MajorProject
	MajorProjects   []MajorProject
}

type RGBColor

type RGBColor struct {
	// contains filtered or unexported fields
}

type SectionStyle

type SectionStyle struct {
	// contains filtered or unexported fields
}

type TechSkill

type TechSkill struct {
	Name      string
	Values    string
	Icon      string
	BrandIcon bool
}

Jump to